==> agr-center-api-3.1.0-CLOUD-TEST-20231213.075412-1-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrMainSaveBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigBo;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigBo;
import com.tydic.dyc.agr.service.agr.bo.AgrMainExtBo;
import java.util.Date;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainSaveBo implements Serializable {
	private static final long serialVersionUID =  -6530517208003219605L;

	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 铺货方式
	 */
	private Integer supplierMode;
	/**
	 * 铺货单位ID
	 */
	private Long managementOrgId;
	/**
	 * 铺货单位名称
	 */
	private String managementOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 付款方式（对供应商）贸易模式必填
	 */
	private AgrPayConfigBo payTypeSup;
	/**
	 * 付款方式（对采购商）贸易模式必填
	 */
	private AgrPayConfigBo payTypePur;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 协议编制时间
	 */
	private Date createTime;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制0：无，1：事前调价，2事中调价 
	 */
	private Integer adjustPrice;
	/**
	 * 是否存在加价项
	 */
	private BigDecimal isAddPrice;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer isAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Long isModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private String adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private Long adjustPriceFormula;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 是否配送
	 */
	private Integer isDispatch;
	/**
	 * 是否分配
	 */
	private Integer isAssign;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExtBo> agrMainExtBOs;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 排序
	 */
	private String orderBy;
	/**
	 * 服务费比例
	 */
	private String serviceRate;
}

==> agr-center-api-3.2.2-CLOUD-TEST-20250206.034529-7-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrMainSaveBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainSaveBo implements Serializable {
	private static final long serialVersionUID =  -6530517208003219605L;

	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 铺货方式
	 */
	private Integer supplierMode;
	/**
	 * 铺货单位ID
	 */
	private String managementOrgId;
	/**
	 * 铺货单位名称
	 */
	private String managementOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 付款方式（对供应商）贸易模式必填
	 */
	private AgrPayConfigBo payTypeSup;
	/**
	 * 付款方式（对采购商）贸易模式必填
	 */
	private AgrPayConfigBo payTypePur;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 协议编制时间
	 */
	private Date createTime;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制0：无，1：事前调价，2事中调价 
	 */
	private Integer adjustPrice;
	/**
	 * 是否存在加价项
	 */
	private BigDecimal isAddPrice;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer isAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Long isModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private String adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private Long adjustPriceFormula;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 是否配送
	 */
	private Integer isDispatch;
	/**
	 * 是否分配
	 */
	private Integer isAssign;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExtBo> agrMainExtBOs;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 协议id
	 */
	private Long agrId;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 铺货方式（铺货方式：1：运营商自主铺货 2：供应商铺货 3:采购单位铺货）
	 */
	private Integer vendorMode;
	/**
	 * 外部关联ID
	 */
	private String relId;
	/**
	 * 外部关联名称
	 */
	private String relName;
	/**
	 * 协议来源ID
	 */
	private String agrSrcId;
	/**
	 * 不含税金额
	 */
	private BigDecimal noTaxAmount;
	/**
	 * 排序
	 */
	private String orderBy;
	/**
	 * 是否代理商
	 */
	private Integer agentFlag;
	/**
	 * 原厂商名称
	 */
	private String originalManufacturer;
	/**
	 * 是否代管供应商
	 */
	private Integer escrowVendorFlag;
	/**
	 * 合同签订依据
	 */
	private String agrMainExtend10;
	/**
	 * 协议创建机构
	 */
	private Long createOrgId;
	/**
	 * 协议创建机构名称
	 */
	private String createOrgName;
	/**
	 * 协议创建公司ID
	 */
	private Long createCompanyId;
	/**
	 * 协议创建公司名称
	 */
	private String createCompanyName;
	/**
	 * 编制人
	 */
	private Long createLoginId;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 是否开放二分 1 是 0 否
	 */
	private Integer secondUserFlag;
}
